checksum - A Simple Error Detection Checksum 16 Bit
======================================

The commandmodule Faraday Python module contains a function(s) that compute a simple 16 bit checksum used for error detection and correct.

.. automodule:: Checksum
    :members:
